==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/ga-IE/activity-stream-strings.js <==
// Note - this is a generated ga-IE file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Cluaisín Nua",
  "header_top_sites": "Barrshuímh",
  "header_highlights": "Highlights",
  "header_recommended_by": "Recommended by {provider}",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "Feicthe",
  "type_label_bookmarked": "Leabharmharcáilte",
  "type_label_recommended": "Treochtáil",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Cruthaigh leabharmharc",
  "menu_action_remove_bookmark": "Scrios an Leabharmharc",
  "menu_action_open_new_window": "Oscail i bhFuinneog Nua",
  "menu_action_open_private_window": "Oscail i bhFuinneog Nua Phríobháideach",
  "menu_action_dismiss": "Ruaig",
  "menu_action_delete": "Scrios ón Stair",
  "menu_action_pin": "Pionnáil",
  "menu_action_unpin": "Díphionnáil",
  "confirm_history_delete_p1": "An bhfuil tú cinnte gur mhaith leat an leathanach seo a scriosadh go hiomlán ó do stair?",
  "confirm_history_delete_notice_p2": "Ní féidir an gníomh seo a chur ar ceal.",
  "menu_action_save_to_pocket": "Sábháil in Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Cuardach",
  "search_header": "Cuardach {search_engine_name}",
  "search_web_placeholder": "Cuardaigh an Gréasán",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "Saincheap an Leathanach do Chluaisín Nua",
  "settings_pane_topsites_header": "Barrshuímh",
  "settings_pane_highlights_header": "Highlights",
  "settings_pane_highlights_options_bookmarks": "Bookmarks",
  "settings_pane_snippets_header": "Snippets",
  "edit_topsites_button_text": "Eagar",
  "edit_topsites_edit_button": "Cuir an suíomh seo in eagar",
  "topsites_form_add_header": "Barrshuíomh Nua",
  "topsites_form_edit_header": "Cuir an Barrshuíomh in Eagar",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "Cuir teideal isteach",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "Clóscríobh nó greamaigh URL",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "Cuir leis",
  "topsites_form_save_button": "Sábháil",
  "topsites_form_cancel_button": "Cealaigh",
  "topsites_form_url_validation": "URL neamhbhailí",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "Topaicí i mbéal an phobail:",
  "pocket_read_even_more": "Tuilleadh Scéalta",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Try Firefox with the bookmarks, history and passwords from another browser.",
  "manual_migration_cancel_button": "No Thanks",
  "manual_migration_import_button": "Import Now",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "Á Lódáil…",
  "header_stories": "Barrscéalta",
  "header_visit_again": "Cuairt Arís",
  "header_bookmarks": "Leabharmharcanna Le Déanaí",
  "header_bookmarks_placeholder": "Níl aon leabharmharcanna agat.",
  "header_stories_from": "ó",
  "type_label_synced": "Sioncronaithe ó ghléas eile",
  "type_label_open": "Oscailte",
  "type_label_topic": "Ábhar",
  "menu_action_copy_address": "Cóipeáil an Seoladh",
  "menu_action_email_link": "Seol an Nasc trí Ríomhphost…",
  "search_for_something_with": "Déan cuardach ar {search_term} le:",
  "search_settings": "Socruithe Cuardaigh",
  "welcome_title": "Fáilte go dtí cluaisín nua",
  "welcome_body": "Úsáidfidh Firefox an spás seo chun na leabharmharcanna, ailt, físeáin, agus leathanaigh is tábhachtaí a thaispeáint duit, ionas go mbeidh tú in ann filleadh orthu gan stró.",
  "welcome_label": "Buaicphointí á lorg",
  "time_label_less_than_minute": "< 1 n",
  "time_label_minute": "{number}n",
  "time_label_hour": "{number}u",
  "time_label_day": "{number}l",
  "settings_pane_header": "Sainroghanna do Chluaisín Nua",
  "settings_pane_body": "Roghnaigh na rudaí a fheicfidh tú nuair a osclóidh tú cluaisín nua.",
  "settings_pane_search_header": "Cuardach",
  "settings_pane_search_body": "Cuardaigh an Gréasán go díreach ón gcluaisín nua.",
  "settings_pane_topsites_body": "Na suímh Ghréasáin a dtugann tú cuairt orthu is minice.",
  "settings_pane_topsites_options_showmore": "Taispeáin dhá shraith",
  "settings_pane_bookmarks_header": "Leabharmharcanna Le Déanaí",
  "settings_pane_bookmarks_body": "Do chuid leabharmharcanna nua in áit amháin.",
  "settings_pane_visit_again_header": "Cuairt Arís",
  "settings_pane_visit_again_body": "Taispeánann Firefox nascanna ó do stair bhrabhsála a mbeadh suim agat filleadh orthu amach anseo.",
  "settings_pane_pocketstories_header": "Barrscéalta",
  "settings_pane_pocketstories_body": "Le Pocket, ball de theaghlach Mozilla, beidh tú ábalta teacht ar ábhar den chéad scoth go héasca.",
  "settings_pane_done_button": "Déanta",
  "edit_topsites_button_label": "Saincheap na Barrshuímh",
  "edit_topsites_showmore_button": "Taispeáin níos mó",
  "edit_topsites_showless_button": "Taispeáin níos lú",
  "edit_topsites_done_button": "Déanta",
  "edit_topsites_pin_button": "Greamaigh an suíomh seo",
  "edit_topsites_unpin_button": "Díghreamaigh an suíomh seo",
  "edit_topsites_dismiss_button": "Ruaig an suíomh seo",
  "edit_topsites_add_button": "Cuir leis",
  "pocket_feedback_header": "Ábhar den chéad scoth ón Ghréasán, le níos mó ná 25 milliún duine i mbun coimeádaíochta.",
  "pocket_feedback_body": "Le Pocket, ball de theaghlach Mozilla, beidh tú ábalta teacht ar ábhar den chéad scoth go héasca.",
  "pocket_send_feedback": "Tabhair Aiseolas Dúinn"
};

==> firefox-62.0b14.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/ga-IE/activity-stream-strings.js <==
// Note - this is a generated ga-IE file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Cluaisín Nua",
  "header_top_sites": "Barrshuímh",
  "header_highlights": "Highlights",
  "header_recommended_by": "Recommended by {provider}",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "Feicthe",
  "type_label_bookmarked": "Leabharmharcáilte",
  "type_label_recommended": "Treochtáil",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Cruthaigh leabharmharc",
  "menu_action_remove_bookmark": "Scrios an Leabharmharc",
  "menu_action_open_new_window": "Oscail i bhFuinneog Nua",
  "menu_action_open_private_window": "Oscail i bhFuinneog Nua Phríobháideach",
  "menu_action_dismiss": "Ruaig",
  "menu_action_delete": "Scrios ón Stair",
  "menu_action_pin": "Pionnáil",
  "menu_action_unpin": "Díphionnáil",
  "confirm_history_delete_p1": "An bhfuil tú cinnte gur mhaith leat an leathanach seo a scriosadh go hiomlán ó do stair?",
  "confirm_history_delete_notice_p2": "Ní féidir an gníomh seo a chur ar ceal.",
  "menu_action_save_to_pocket": "Sábháil in Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Cuardach",
  "search_header": "Cuardach {search_engine_name}",
  "search_web_placeholder": "Cuardaigh an Gréasán",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "Saincheap an Leathanach do Chluaisín Nua",
  "settings_pane_topsites_header": "Barrshuímh",
  "settings_pane_highlights_header": "Highlights",
  "settings_pane_highlights_options_bookmarks": "Bookmarks",
  "settings_pane_snippets_header": "Snippets",
  "edit_topsites_button_text": "Eagar",
  "edit_topsites_edit_button": "Cuir an suíomh seo in eagar",
  "topsites_form_add_header": "Barrshuíomh Nua",
  "topsites_form_edit_header": "Cuir an Barrshuíomh in Eagar",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "Cuir teideal isteach",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "Clóscríobh nó greamaigh URL",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "Cuir leis",
  "topsites_form_save_button": "Sábháil",
  "topsites_form_cancel_button": "Cealaigh",
  "topsites_form_url_validation": "URL neamhbhailí",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "Topaicí i mbéal an phobail:",
  "pocket_read_even_more": "Tuilleadh Scéalta",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Try Firefox with the bookmarks, history and passwords from another browser.",
  "manual_migration_cancel_button": "No Thanks",
  "manual_migration_import_button": "Import Now",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_manage_webext": "Manage Extension",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "firstrun_title": "Take Firefox with You",
  "firstrun_content": "Get your bookmarks, history, passwords and other settings on all your devices.",
  "firstrun_learn_more_link": "Learn more about Firefox Accounts",
  "firstrun_form_header": "Enter your email",
  "firstrun_form_sub_header": "to continue to Firefox Sync",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_extra_legal_links": "By proceeding, you agree to the {terms} and {privacy}.",
  "firstrun_terms_of_service": "Terms of Service",
  "firstrun_privacy_notice": "Privacy Notice",
  "firstrun_continue_to_login": "Continue",
  "firstrun_skip_login": "Skip this step",
  "default_label_loading": "Á Lódáil…",
  "header_stories": "Barrscéalta",
  "header_visit_again": "Cuairt Arís",
  "header_bookmarks": "Leabharmharcanna Le Déanaí",
  "header_bookmarks_placeholder": "Níl aon leabharmharcanna agat.",
  "header_stories_from": "ó",
  "type_label_synced": "Sioncronaithe ó ghléas eile",
  "type_label_open": "Oscailte",
  "type_label_topic": "Ábhar",
  "menu_action_copy_address": "Cóipeáil an Seoladh",
  "menu_action_email_link": "Seol an Nasc trí Ríomhphost…",
  "search_for_something_with": "Déan cuardach ar {search_term} le:",
  "search_settings": "Socruithe Cuardaigh",
  "welcome_title": "Fáilte go dtí cluaisín nua",
  "welcome_body": "Úsáidfidh Firefox an spás seo chun na leabharmharcanna, ailt, físeáin, agus leathanaigh is tábhachtaí a thaispeáint duit, ionas go mbeidh tú in ann filleadh orthu gan stró.",
  "welcome_label": "Buaicphointí á lorg",
  "time_label_less_than_minute": "< 1 n",
  "time_label_minute": "{number}n",
  "time_label_hour": "{number}u",
  "time_label_day": "{number}l",
  "settings_pane_header": "Sainroghanna do Chluaisín Nua",
  "settings_pane_body": "Roghnaigh na rudaí a fheicfidh tú nuair a osclóidh tú cluaisín nua.",
  "settings_pane_search_header": "Cuardach",
  "settings_pane_search_body": "Cuardaigh an Gréasán go díreach ón gcluaisín nua.",
  "settings_pane_topsites_body": "Na suímh Ghréasáin a dtugann tú cuairt orthu is minice.",
  "settings_pane_topsites_options_showmore": "Taispeáin dhá shraith",
  "settings_pane_bookmarks_header": "Leabharmharcanna Le Déanaí",
  "settings_pane_bookmarks_body": "Do chuid leabharmharcanna nua in áit amháin.",
  "settings_pane_visit_again_header": "Cuairt Arís",
  "settings_pane_visit_again_body": "Taispeánann Firefox nascanna ó do stair bhrabhsála a mbeadh suim agat filleadh orthu amach anseo.",
  "settings_pane_pocketstories_header": "Barrscéalta",
  "settings_pane_pocketstories_body": "Le Pocket, ball de theaghlach Mozilla, beidh tú ábalta teacht ar ábhar den chéad scoth go héasca.",
  "settings_pane_done_button": "Déanta",
  "edit_topsites_button_label": "Saincheap na Barrshuímh",
  "edit_topsites_showmore_button": "Taispeáin níos mó",
  "edit_topsites_showless_button": "Taispeáin níos lú",
  "edit_topsites_done_button": "Déanta",
  "edit_topsites_pin_button": "Greamaigh an suíomh seo",
  "edit_topsites_unpin_button": "Díghreamaigh an suíomh seo",
  "edit_topsites_dismiss_button": "Ruaig an suíomh seo",
  "edit_topsites_add_button": "Cuir leis",
  "pocket_feedback_header": "Ábhar den chéad scoth ón Ghréasán, le níos mó ná 25 milliún duine i mbun coimeádaíochta.",
  "pocket_feedback_body": "Le Pocket, ball de theaghlach Mozilla, beidh tú ábalta teacht ar ábhar den chéad scoth go héasca.",
  "pocket_send_feedback": "Tabhair Aiseolas Dúinn"
};
